pub struct AccountBalance {
pub currency: Currency,
pub total: Money,
pub locked: Money,
pub free: Money,
}Expand description
Represents an account balance denominated in a particular currency.
Fields
currency: CurrencyThe account balance currency.
total: MoneyThe total account balance.
locked: MoneyThe account balance locked (assigned to pending orders).
free: MoneyThe account balance free for trading.
Implementations
Sourceimpl AccountBalance
impl AccountBalance
Sourcepub fn new_checked(total: Money, locked: Money, free: Money) -> Result<Self>
pub fn new_checked(total: Money, locked: Money, free: Money) -> Result<Self>
Creates a new AccountBalance instance with correctness checking.
Errors
Returns an error if total is not the result of locked + free.
Notes
PyO3 requires a Result type that stacktrace can be printed for errors.
Sourcepub fn new(total: Money, locked: Money, free: Money) -> Self
pub fn new(total: Money, locked: Money, free: Money) -> Self
Creates a new AccountBalance instance.
Panics
Panics if a correctness check fails. See AccountBalance::new_checked for more details.
Sourceimpl AccountBalance
impl AccountBalance
Sourcepub fn py_from_dict(values: &Bound<'_, PyDict>) -> PyResult<Self>
pub fn py_from_dict(values: &Bound<'_, PyDict>) -> PyResult<Self>
Constructs an AccountBalance from a Python dict.
Errors
Returns a PyErr if parsing or conversion fails.
Panics
Panics if parsing numeric values (unwrap()) fails due to invalid format.
Sourcepub fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>
pub fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>